@@ -9,16 +9,19 @@ use MIDI::RtController::Filter::CC ();
 my $input_name  = shift || 'joystick';
 my $output_name = shift || 'usb';
 
-my $rtc = MIDI::RtController->new(
+my $control = MIDI::RtController->new(
     input   => $input_name,
     output  => $output_name,
     verbose => 1,
 );
 
-my $rtf = MIDI::RtController::Filter::CC->new(rtc => $rtc);
+my $filter = MIDI::RtController::Filter::CC->new(rtc => $control);
 
-$rtc->add_filter('breathe', ['all'], $rtf->curry::breathe);
+# $control->add_filter('breathe', ['all'], $filter->curry::breathe);
 
-$rtc->run;
+$filter->time_step(500_000);
+$control->add_filter('scatter', ['all'], $filter->curry::scatter);
+
+$control->run;
 
 # ...and now trigger a MIDI message!
