@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Control-change based RtController filters
 
-our $VERSION = '0.0104';
+our $VERSION = '0.0200';
 
 use v5.36;
 
@@ -103,6 +103,26 @@ sub breathe ($self, $device, $dt, $event) {
     return 0;
 }
 
+
+sub scatter ($self, $device, $dt, $event) {
+    return 0 if $self->running;
+
+    my ($ev, $chan, $ctl, $val) = $event->@*;
+
+    $self->running(1);
+
+    my @values = (0 .. 127);
+
+    while (!$self->stop) {
+        my $value = $values[ int rand @values ];
+        my $cc = [ 'control_change', $self->channel, $self->control, $value ];
+        $self->rtc->send_it($cc);
+        usleep $self->time_step;
+    }
+
+    return 0;
+}
+
 1;
 
 __END__
@@ -117,7 +137,7 @@ MIDI::RtController::Filter::CC - Control-change based RtController filters
 
 =head1 VERSION
 
-version 0.0104
+version 0.0200
 
 =head1 SYNOPSIS
 
@@ -258,7 +278,7 @@ Return a new C<MIDI::RtController::Filter::CC> object.
 
   $control->add_filter('breathe', all => $filter->curry::breathe);
 
-This filter sets the B<running> flag and then iterates between the
+This filter sets the B<running> flag, then iterates between the
 B<range_bottom> and B<range_top> by B<range_step> increments, sending
 a B<control> change message, over the MIDI B<channel> every iteration,
 until B<stop> is seen.
@@ -266,6 +286,18 @@ until B<stop> is seen.
 Passing C<all> means that any MIDI event will cause this filter to be
 triggered.
 
+=head2 scatter
+
+  $control->add_filter('scatter', all => $filter->curry::scatter);
+
+This filter sets the B<running> flag, chooses a random number between
+the B<range_bottom> and B<range_top>, and sends that as the value of a
+B<control> change message, over the MIDI B<channel>, every iteration,
+until B<stop> is seen.
+
+Passing C<all> means that any MIDI event will cause this filter to be
+triggered.
+
 =head1 SEE ALSO
 
 L<Iterator::Breathe>
